@@ -3,8 +3,8 @@ use std::{borrow::Cow, sync::Arc};
 
 pub trait Backward {
     // We don't think backward persistent makes sense.
-    fn get_backward_transient<K: AsRef<str>>(&self, key: K) -> Option<Cow<'static, str>>;
-    fn get_backward_downstream<K: AsRef<str>>(&self, key: K) -> Option<Cow<'static, str>>;
+    fn get_backward_transient<K: AsRef<str>>(&self, key: K) -> Option<&str>;
+    fn get_backward_downstream<K: AsRef<str>>(&self, key: K) -> Option<&str>;
 
     fn get_all_backward_transients(&self) -> Option<&Vec<Arc<KV>>>;
     fn get_all_backward_downstreams(&self) -> Option<&Vec<Arc<KV>>>;
